/*
Arduipiano : giant piano to play with the feet
Created 31 march 2022 by François THOMAS
This code is released to the public domain. For information about the circuit,
visit the Instructable tutorial

*/
#include <CapacitiveSensor.h>  // Importe la bibliothèque capacitivesensor

CapacitiveSensor   cs_2_25 = CapacitiveSensor(2, 25); // do
CapacitiveSensor   cs_2_24 = CapacitiveSensor(2, 24); // do#
CapacitiveSensor   cs_2_23 = CapacitiveSensor(2, 23); // ré
CapacitiveSensor   cs_2_22 = CapacitiveSensor(2, 22); // ré#
CapacitiveSensor   cs_2_3 = CapacitiveSensor(2, 3); // mi
CapacitiveSensor   cs_2_4 = CapacitiveSensor(2, 4); // fa
CapacitiveSensor   cs_2_5 = CapacitiveSensor(2, 5); // fa#
CapacitiveSensor   cs_2_6 = CapacitiveSensor(2, 6); // sol
CapacitiveSensor   cs_2_7 = CapacitiveSensor(2, 7); // sol#
CapacitiveSensor   cs_2_8 = CapacitiveSensor(2, 8); // la
CapacitiveSensor   cs_2_9 = CapacitiveSensor(2, 9); // la#
CapacitiveSensor   cs_2_10 = CapacitiveSensor(2, 10); // si

const int notes = 12;        // nombre de notes jouées

boolean notePlaying[notes] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };     //tableau d'états de note : garde une trace si un déclencheur est "On" ou "OFF"
int scale[notes] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11};              //echelle de note
int beginNote = 0x3C;    //valeur de la note de départ (Do 4 : 523 Hz)

int seuil = 130;         // permet de régler le seuil pour tous les capteurs

void setup()
{
  cs_2_25.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_24.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_23.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_22.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_3.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_4.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_5.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_6.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_7.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_8.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_9.set_CS_AutocaL_Millis(0xFFFFFFFF);
  cs_2_10.set_CS_AutocaL_Millis(0xFFFFFFFF);

  Serial.begin(57600);            // communication serie pour afficher des messages sur le PC
  Serial3.begin(31250);           // communication MIDI

}

void loop()
{
  long sensors[notes] = {
    cs_2_25.capacitiveSensor(50),
    cs_2_24.capacitiveSensor(50),
    cs_2_23.capacitiveSensor(50),
    cs_2_22.capacitiveSensor(50),
    cs_2_3.capacitiveSensor(50),
    cs_2_4.capacitiveSensor(50),
    cs_2_5.capacitiveSensor(50),
    cs_2_6.capacitiveSensor(50),
    cs_2_7.capacitiveSensor(50),
    cs_2_8.capacitiveSensor(50),
    cs_2_9.capacitiveSensor(50),
    cs_2_10.capacitiveSensor(50),

  };

  for (int i = 0; i < notes; i++) {               //parcourt toutes les notes

    if ((sensors[i] >= seuil) && (notePlaying[i] == false)) { //note on & CC messages
      int note = beginNote + scale[i];
      midiMessage(0x90, note, 100);               //0x90 = NOTE ON MESSAGE
      notePlaying[i] = true;
    }

    if ((sensors[i] < seuil) && (notePlaying[i] == true)) { //note off messages
      int note = beginNote + scale[i];
      midiMessage(0x80, note, 0);                 //0x80 = NOTE OFF MESSAGE
      notePlaying[i] = false;
    }

    //Affichage des capacites de chaque touche :
 Serial.print(sensors[i]); //valeur de la touche
 Serial.print("\t");       //tabulation pour espacer les valeurs sur le moniteur serie
  }
 Serial.println("");       //retour a la ligne apres avoir affiche toutes les notes

}

//fonction pour l'envoi des notes a l'ordinateur avec le protocole midi
void midiMessage(int commandByte, int data1Byte, int data2Byte) {
  Serial3.write(commandByte);
  Serial3.write(data1Byte);
  Serial3.write(data2Byte);
}
